#ifndef NT2_INCLUDE_CONSTANTS_TWOOPI_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_TWOOPI_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/twoopi.hpp>

#endif
